<%@ Page Language="C#" Debug="false" Trace="false" EnableViewState="false" %>
<%@ import Namespace="System" %>
<%@ import Namespace="System.IO" %>
<%@ import Namespace="System.Xml" %>
<%@ import Namespace="System.Data" %>
<%@ import Namespace="System.Text" %>
<script runat="server">

    // ################ Settings ################
    const string COMIC_DIRECTORY = @"Comics\";

    int iComicID;
    string sComicFile;

    XmlDocument xmlDoc = new XmlDocument(); // The comic XML file

    void Page_Load (Object sender, EventArgs e)
    {
        // No caching
        Response.Cache.SetNoStore();
        
        // Is a new comic ID required?
        if (Request.QueryString["newcomicid"] != null)
        { // Yes

            Response.ContentType = "text/xml";
            Response.Write("<data comicid=\"" + NewComicID().ToString() + "\" ></data>");
        }
        else 
        { // No - save data

            // Global data
            iComicID = Convert.ToInt32(Request.QueryString["comicid"]);
            sComicFile = Server.MapPath(COMIC_DIRECTORY) + iComicID + ".xml";

            int iMode = Convert.ToInt32(Request.QueryString["m"]);

            // Operational mode
            switch (iMode)
            {
                case 0: // Create comic XML 
                    CreateComic();
                    break;
                case 1: // Save panel
                    CreatePanel();
                    break;
                case 2: // Save sprite
                    CreateSprite();
                    break;
                case 3: // Save textbox
                    CreateTextbox();
                    break;
            }
        }
    }
    
    // Work out the next available comic ID
    int NewComicID()
    {
        int iComicID = 1;
        
        DirectoryInfo di = new DirectoryInfo( Server.MapPath( COMIC_DIRECTORY ) );
        FileInfo[] rgFiles = di.GetFiles("*.xml");
        foreach (FileInfo fi in rgFiles)
        {
            Trace.Write(fi.Name);
            int iFileComicID = Convert.ToInt32(fi.Name.Replace(".xml", string.Empty));
            if (iFileComicID >= iComicID)
            {
                iComicID = iFileComicID + 1;
                Trace.Write("iComicID set to " + iComicID.ToString());
            }
        }

        return iComicID;
    }
    
    void CreateComic()
    {
        Trace.Write( "CreateComic()" );
        
        // If comic already exists - extract created date
        DateTime dtCreated = DateTime.Now;
        
        if (File.Exists(sComicFile))
        {
            Trace.Write("Comic already exists");
            XmlDocument xmlComic = new XmlDocument();
            xmlComic.Load(sComicFile);
            dtCreated = Convert.ToDateTime(xmlComic.DocumentElement.Attributes["DateCreated"].Value);
        }

        // Create comic XML file
        XmlTextWriter xmlWriter = new XmlTextWriter(sComicFile, System.Text.Encoding.UTF8);
        xmlWriter.Formatting = Formatting.Indented;
        xmlWriter.WriteProcessingInstruction("xml", "version='1.0' encoding='UTF-8'");
        xmlWriter.WriteStartElement("Comic");       
        xmlWriter.Close();
            
        xmlDoc.Load( sComicFile );
         
        // Comic settings
        XmlNode oRoot = xmlDoc.DocumentElement;
        XmlElement oComic = (XmlElement) oRoot;
        
        // Comic header
        oComic.SetAttribute("Name", Request.QueryString["name"] );
        oComic.SetAttribute("PanelLayoutID", Request.QueryString["layoutid"] );
        oComic.SetAttribute("DateCreated", dtCreated.ToString() );
        oComic.SetAttribute("DatePublish", Request.QueryString["publishDate"]);
        oComic.SetAttribute("DateModified", DateTime.Now.ToString());


        // Save changes
        xmlDoc.Save(sComicFile);            
    }

    // Create a panel within the comic
    void CreatePanel()
    {
        Trace.Write("CreatePanel()");
        
        // Load comic XML
        xmlDoc.Load(sComicFile);
        XmlNode root = xmlDoc.DocumentElement;
        
        // Panel data
        int iPanelID = Convert.ToInt32(Request.QueryString["id"]);
        string sBackgroundImage = Request.QueryString["bg"];

        // Create panel
        XmlElement oPanel = xmlDoc.CreateElement("Panel");
        oPanel.SetAttribute("ID", iPanelID.ToString());
        oPanel.SetAttribute("BackgroundImage", sBackgroundImage);
        root.AppendChild(oPanel);
        
        // Save changes
        xmlDoc.Save(sComicFile); 
    }
    
    // Create a sprite within a panel
    void CreateSprite()
    {
        Trace.Write("CreateSprite()");

        // Load comic XML
        xmlDoc.Load(sComicFile);
        XmlNode root = xmlDoc.DocumentElement;
      
        // Create sprite
        XmlElement oSprite = xmlDoc.CreateElement("Sprite");
        oSprite.SetAttribute("x", Request.QueryString["x"]);
        oSprite.SetAttribute("y", Request.QueryString["y"]);
        oSprite.SetAttribute("width", Request.QueryString["w"]);
        oSprite.SetAttribute("height", Request.QueryString["h"]);
        oSprite.SetAttribute("alpha", Request.QueryString["alpha"]);
        oSprite.SetAttribute("Image", Request.QueryString["src"]);
        oSprite.SetAttribute("flip", Request.QueryString["flip"]);
        oSprite.SetAttribute("locked", Request.QueryString["locked"]);
        oSprite.SetAttribute("zIndex", Request.QueryString["zIndex"]);

        // Search for sprite panel
        int iPanelID = Convert.ToInt32(Request.QueryString["pid"]);
        XmlNode oPanel = xmlDoc.ChildNodes[1];

        for (int i = 0; i < xmlDoc.ChildNodes[1].ChildNodes.Count; i++)
        {
            oPanel = xmlDoc.ChildNodes[1].ChildNodes[i];
            if (oPanel.Attributes["ID"].Value == iPanelID.ToString())
                break;
        }
        
        // Add sprite to panel
        oPanel.AppendChild(oSprite);

        // Save changes
        xmlDoc.Save(sComicFile);         
    }
    
    // Create a textbox within a panel
    void CreateTextbox()
    {
        Trace.Write("CreateTextbox()");

        // Load comic XML
        xmlDoc.Load(sComicFile);
        XmlNode root = xmlDoc.DocumentElement;

        // Create textbox
        XmlElement oTextbox = xmlDoc.CreateElement("Textbox");
        oTextbox.SetAttribute("x", Request.QueryString["x"]);
        oTextbox.SetAttribute("y", Request.QueryString["y"]);
        oTextbox.SetAttribute("width", Request.QueryString["w"]);
        oTextbox.SetAttribute("height", Request.QueryString["h"]);
        oTextbox.SetAttribute("text", Request.QueryString["text"]);
        oTextbox.SetAttribute("fontName", Request.QueryString["fontName"]);
        oTextbox.SetAttribute("fontSize", Request.QueryString["fontSize"]);
        oTextbox.SetAttribute("fontStyle", Request.QueryString["fontStyle"]);
        oTextbox.SetAttribute("fontWeight", Request.QueryString["fontWeight"]);
        oTextbox.SetAttribute("colour", Request.QueryString["colour"]);
        oTextbox.SetAttribute("backgroundColour", Request.QueryString["backgroundColour"]);
        oTextbox.SetAttribute("borderWidth", Request.QueryString["borderWidth"]);
        oTextbox.SetAttribute("borderStyle", Request.QueryString["borderStyle"]);
        oTextbox.SetAttribute("borderColour", Request.QueryString["borderColour"]);
        oTextbox.SetAttribute("alpha", Request.QueryString["alpha"]);
        oTextbox.SetAttribute("flip", Request.QueryString["flip"]);
        oTextbox.SetAttribute("textAlign", Request.QueryString["textAlign"]);
        oTextbox.SetAttribute("locked", Request.QueryString["locked"]);
        oTextbox.SetAttribute("tailX", Request.QueryString["tailX"]);
        oTextbox.SetAttribute("tailY", Request.QueryString["tailY"]);
        oTextbox.SetAttribute("tailEnabled", Request.QueryString["tailEnabled"]);
        oTextbox.SetAttribute("zIndex", Request.QueryString["zIndex"]);

        // Search for textbox panel
        int iPanelID = Convert.ToInt32(Request.QueryString["pid"]);
        XmlNode oPanel = xmlDoc.ChildNodes[1];

        for (int i = 0; i < xmlDoc.ChildNodes[1].ChildNodes.Count; i++)
        {
            oPanel = xmlDoc.ChildNodes[1].ChildNodes[i];
            if (oPanel.Attributes["ID"].Value == iPanelID.ToString())
                break;
        }

        // Add textbox to panel
        oPanel.AppendChild(oTextbox);

        // Save changes
        xmlDoc.Save(sComicFile); 
    }

</script>