<%@ Page Language="C#" Debug="false" Trace="false" EnableViewState="false" %>
<%@ import Namespace="System" %>
<%@ import Namespace="System.IO" %>
<%@ import Namespace="System.Xml" %>
<%@ import Namespace="System.Data" %>
<%@ import Namespace="System.Text" %>
<%@ import Namespace="System.Drawing" %>
<script runat="server">
    
    // ################ Settings ################
    const int PREVIEW_MAXHEIGHT = 100;
    const int PREVIEW_MAXWIDTH = 100;


    const string SPRITE_DIRECTORY = @"Sprites\";
    const string BACKGROUND_DIRECTORY = @"Backgrounds\";
    
    // Cache settings (Hold generated JavaScript)
    const string CACHE_SPRITECOLLECTIONS = "Cache_SpriteCollections"; 
    const string CACHE_BACKGROUNDCOLLECTIONS = "Cache_BackgroundCollections"; 
    const string CACHE_PANELLAYOUTS = "Cache_PanelLayouts";
    
    
    void Page_Load (Object sender, EventArgs e)
    {
        // Check user is valid
        CheckUserIsValid();

        LoadPanelLayouts();

        LoadSpriteFolders();
        LoadSprites();

        LoadBackgroundFolders();
        LoadBackgrounds();

        SettingTextProperties();
        SettingMisc();
    }

    // Check user is valid
    void CheckUserIsValid()
    {
		// Security is enabled/disabled via the Web.Config
		if( Convert.ToBoolean( ConfigurationSettings.AppSettings["UserSecurityEnabled"] ) )
	        if ( Session["StrifeStrife_UserID"] == null )
	            Response.Redirect( "../Login.aspx" );
    }

    // Set-up misc properties
    void SettingMisc()
    {
        // Publish date
        ComicPublishYear.Items.Clear();
        for ( int iYear = 2007; iYear <= DateTime.Now.Year + 2; iYear++ )
            ComicPublishYear.Items.Add( iYear.ToString() );

        ComicPublishMonth.Items.Clear();
        for (int iMonth = 1; iMonth <= 12; iMonth++)
            ComicPublishMonth.Items.Add( new ListItem( new DateTime(2000,iMonth,1).ToString("MMMM"), iMonth.ToString() ));

        ComicPublishDay.Items.Clear();
        for (int iDay = 1; iDay <= 31; iDay++)
            ComicPublishDay.Items.Add(iDay.ToString());  
        
        // Set to today's date      
        ComicPublishYear.Items.FindByValue(DateTime.Now.Year.ToString()).Selected = true;
        ComicPublishMonth.Items.FindByValue(DateTime.Now.Month.ToString()).Selected = true;
        ComicPublishDay.Items.FindByValue(DateTime.Now.Day.ToString()).Selected = true;
    }
        
    // Create text box properties
    void SettingTextProperties()
    {
        // Font names
        ddlFontName.Items.Clear();
        
        System.Drawing.FontFamily[] oFonts = new System.Drawing.Text.InstalledFontCollection().Families;
        for (int i = 0; i < oFonts.Length; i++)
            ddlFontName.Items.Add(new ListItem(oFonts[i].Name, oFonts[i].Name));
                
        // Font Colour
        ddlFontColour.Items.Clear();

        System.Drawing.KnownColor enumColor = new System.Drawing.KnownColor();
        Array oColors = Enum.GetValues(enumColor.GetType());

        foreach (object oColor in oColors)
            if (!Color.FromKnownColor((KnownColor)oColor).IsSystemColor) // No system colours
            {
                ddlFontColour.Items.Add(new ListItem(oColor.ToString(), oColor.ToString()));
                ddlFontColour.Items[ddlFontColour.Items.Count - 1].Attributes.Add("style", "color:" + oColor.ToString());
            }
        
        // Size
        ddlFontSize.Items.Clear();

        for (int i = 8; i <= 36; i++)
            ddlFontSize.Items.Add(i.ToString());
        
        // Alignment
        ddlFontAlign.Items.Clear();

        ddlFontAlign.Items.Add(new ListItem("Left", "left"));
        ddlFontAlign.Items.Add(new ListItem("Center", "center"));
        ddlFontAlign.Items.Add(new ListItem("Right", "right"));
        
        // Border width
        ddlBorderWidth.Items.Clear();

        for (int i = 0; i <= 10; i++)
            ddlBorderWidth.Items.Add(i.ToString());
       
        
        // Border style
        ddlBorderStyle.Items.Clear();
        
        ddlBorderStyle.Items.Add(new ListItem("Solid", "solid"));
        ddlBorderStyle.Items.Add(new ListItem("Dotted", "dotted"));
        ddlBorderStyle.Items.Add(new ListItem("Dashed", "dashed"));
        
        // Border colour
        ddlBorderColour.Items.Clear();

        foreach (object oColor in oColors)
            if (!Color.FromKnownColor((KnownColor)oColor).IsSystemColor) // No system colours
            {
                ddlBorderColour.Items.Add(new ListItem(oColor.ToString(), oColor.ToString()));
                ddlBorderColour.Items[ddlBorderColour.Items.Count - 1].Attributes.Add("style", "color:" + oColor.ToString());
            }   
        
        // Background colour
        ddlBackgroundColour.Items.Clear();
        
        foreach (object oColor in oColors)
            if (!Color.FromKnownColor((KnownColor)oColor).IsSystemColor) // No system colours
            {
                ddlBackgroundColour.Items.Add(new ListItem(oColor.ToString(), oColor.ToString()));
                ddlBackgroundColour.Items[ddlBackgroundColour.Items.Count - 1].Attributes.Add("style", "color:" + oColor.ToString());
            }        
        
        // Alpha  
        ddlAlpha.Items.Clear();

        for (int i = 0; i <= 100; i+=10)
            ddlAlpha.Items.Add(new ListItem(i.ToString() + "%", i.ToString()));

        
        // Default settings       
        ddlFontSize.Items.FindByValue("12").Selected = true;
        ddlFontColour.Items.FindByValue("Black").Selected = true;
        
        ddlBorderWidth.Items.FindByValue("1").Selected = true;
        ddlBorderColour.Items.FindByValue("Black").Selected = true;

        ddlBackgroundColour.Items.FindByValue("White").Selected = true;
        ddlAlpha.Items.FindByValue("100").Selected = true;
    }

    // Load sprite folders
    void LoadSpriteFolders()
    {
        ddlSpriteFolders.Items.Clear();

        DirectoryInfo oDirectoryInfo = new DirectoryInfo(Server.MapPath(SPRITE_DIRECTORY ));
        DirectoryInfo[] oDirectories = oDirectoryInfo.GetDirectories();

        foreach (DirectoryInfo oDirectory in oDirectories)
        {
            // How many sprites are there in the directory?
            int iSpriteCount = oDirectory.GetFiles("*.*").Length;

            ddlSpriteFolders.Items.Add(new ListItem(string.Format("{0} ({1})", oDirectory.Name, iSpriteCount), oDirectory.Name));
        }
    }
    
    // Load all the sprites
    void LoadSprites()
    {
        // Is the sprite JavaScript collection already cached?
        if (Cache[CACHE_SPRITECOLLECTIONS] == null)
        { // No - Generate it

            Trace.Write("Sprite", "Not cached - Regenerating");

            StringBuilder sbHTML = new StringBuilder();

            // Load sprites into JavaScript arrays
            DirectoryInfo oDirectoryInfo = new DirectoryInfo(Server.MapPath(SPRITE_DIRECTORY));
            DirectoryInfo[] oDirectories = oDirectoryInfo.GetDirectories();

            sbHTML.Append(string.Format("var oSpriteCollections = new Array({0}); {1}", oDirectories.Length, Environment.NewLine));

            // Loop through each sprite directory
            int iCollectionID = 0;
            foreach (DirectoryInfo oDirectory in oDirectories)
            {
                sbHTML.Append(string.Format("oSpriteCollections[{0}] = new Array(", iCollectionID));

                // Add sprites in directory
                FileInfo[] oFiles = oDirectory.GetFiles("*.*");
                foreach (FileInfo oFile in oFiles)
                {
                    Trace.Write("Sprite", "Loading " + oFile.FullName);

                    // Load image
                    using (System.Drawing.Bitmap bmpSprite = new System.Drawing.Bitmap(oFile.FullName))
                    {

                        // Work out preview width/height
                        int iPreviewHeight = bmpSprite.Height;
                        int iPreviewWidth = bmpSprite.Width;

                        // Calculate sprite preview dimensions
                        CalcPreviewDimensions(ref iPreviewHeight, ref iPreviewWidth);

                        sbHTML.Append(string.Format(" new Sprite('{0}', '{1}', {2}, {3}, {4}, {5}),",
                                                    SPRITE_DIRECTORY.Replace("\\", "/") + oDirectory.Name + "/" + oFile.Name, // src 
                                                    oFile.Name, // filename 
                                                    bmpSprite.Width, // width
                                                    bmpSprite.Height, // height
                                                    iPreviewWidth, // preview width
                                                    iPreviewHeight)); // preview height

                    }
                }

                // Remove the last comma, if there were files
                if (oFiles.Length > 0)
                    sbHTML.Remove(sbHTML.Length - 1, 1);

                sbHTML.Append(");" + Environment.NewLine);
                iCollectionID++;
            }

            litJS_SpriteCollections.Text = sbHTML.ToString();
            
            // Cache generated code
            Cache[CACHE_SPRITECOLLECTIONS] = sbHTML.ToString();
        }
        else
        { // Return cached code

            Trace.Write("Sprite", "Cached - Using cached code");

            litJS_SpriteCollections.Text = (string) Cache[CACHE_SPRITECOLLECTIONS];
        }
    }

    // Load background folders
    void LoadBackgroundFolders()
    {
        ddlBackgroundFolders.Items.Clear();

        DirectoryInfo oDirectoryInfo = new DirectoryInfo(Server.MapPath(BACKGROUND_DIRECTORY));
        DirectoryInfo[] oDirectories = oDirectoryInfo.GetDirectories();

        foreach (DirectoryInfo oDirectory in oDirectories)
        {
            // How many backgrounds are there in the directory?
            int iBackgroundCount = oDirectory.GetFiles("*.*").Length;

            ddlBackgroundFolders.Items.Add(new ListItem(string.Format("{0} ({1})", oDirectory.Name, iBackgroundCount), oDirectory.Name));
        }
    }    
    
    // Load all the backgrounds
    void LoadBackgrounds()
    {
        // Is the sprite JavaScript collection already cached?
        if (Cache[CACHE_BACKGROUNDCOLLECTIONS] == null)
        { // No - Generate it

            Trace.Write("Background", "Not cached - Regenerating");

            StringBuilder sbHTML = new StringBuilder();


            // Load backgrounds into JavaScript arrays
            DirectoryInfo oDirectoryInfo = new DirectoryInfo(Server.MapPath(BACKGROUND_DIRECTORY));
            DirectoryInfo[] oDirectories = oDirectoryInfo.GetDirectories();

            sbHTML.Append(string.Format("var oBackgroundCollections = new Array({0}); {1}", oDirectories.Length, Environment.NewLine));

            // Loop through each background directory
            int iCollectionID = 0;
            foreach (DirectoryInfo oDirectory in oDirectories)
            {
                sbHTML.Append(string.Format("oBackgroundCollections[{0}] = new Array(", iCollectionID));

                // Add sprites in directory
                FileInfo[] oFiles = oDirectory.GetFiles("*.*");
                foreach (FileInfo oFile in oFiles)
                {
                    Trace.Write("Background", "Loading " + oFile.FullName);

                    // Load image
                    using (System.Drawing.Bitmap bmpSprite = new System.Drawing.Bitmap(oFile.FullName))
                    {

                        // Work out preview width/height
                        int iPreviewHeight = bmpSprite.Height;
                        int iPreviewWidth = bmpSprite.Width;

                        // Calculate background preview dimensions
                        CalcPreviewDimensions(ref iPreviewHeight, ref iPreviewWidth);

                        sbHTML.Append(string.Format(" new Sprite('{0}', '{1}', {2}, {3}, {4}, {5}),",
                                                    FormatForJavaScript( BACKGROUND_DIRECTORY.Replace("\\", "/") + oDirectory.Name + "/" + oFile.Name ), // src 
                                                    FormatForJavaScript( oFile.Name ), // filename 
                                                    bmpSprite.Width, // width
                                                    bmpSprite.Height, // height
                                                    iPreviewWidth, // preview width
                                                    iPreviewHeight)); // preview height

                    }
                }

                // Remove the last comma, if there were files
                if (oFiles.Length > 0)
                    sbHTML.Remove(sbHTML.Length - 1, 1);

                sbHTML.Append(");" + Environment.NewLine);
                iCollectionID++;
            }

            litJS_BackgroundCollections.Text = sbHTML.ToString();
            
            // Cache generated code
            Cache[CACHE_BACKGROUNDCOLLECTIONS] = sbHTML.ToString();
        }
        else
        { // Return cached code

            Trace.Write("Background", "Cached - Using cached code");

            litJS_BackgroundCollections.Text = (string)Cache[CACHE_BACKGROUNDCOLLECTIONS];
        }        
    }    

    // Load different types of comic panel layout from XML into JavaScript
    void LoadPanelLayouts()
    {
        if (Cache[CACHE_PANELLAYOUTS] == null)
        {
            Trace.Write("Panels", "Not cached - Generating code");
            
            using (FileStream oFS = new FileStream(Server.MapPath("PanelLayouts.XML"), FileMode.Open, FileAccess.Read, FileShare.ReadWrite))
            {
                StringBuilder sbJS = new StringBuilder();
                XmlDocument oXmlDoc = new XmlDocument();
                oXmlDoc.Load(oFS);
                XmlNodeList oXmlNode = oXmlDoc.GetElementsByTagName("layout");

                Trace.Write("There are " + oXmlNode.Count.ToString() + " panel layouts");

                sbJS.Append(string.Format("var oPanelLayouts = new Array({0});", oXmlNode.Count));
                sbJS.Append(Environment.NewLine);

                // Loop through and create each panel layout
                for (int i = 0; i < oXmlNode.Count; i++)
                {
                    XmlAttributeCollection oXmlAttrib = oXmlNode[i].Attributes;

                    Trace.Write("Panel layout " + (i + 1).ToString());
                    Trace.Write("Name: " + oXmlAttrib["name"].Value);

                    StringBuilder sbPanelLayout = new StringBuilder();
                    sbPanelLayout.Append(string.Format("oPanelLayouts[{0}] = new Array(", i));

                    // Add name, width and height of panel layout
                    sbPanelLayout.Append(string.Format("'{0}', {1}, {2}, ",
                                                         oXmlAttrib["name"].Value,
                                                         oXmlAttrib["width"].Value,
                                                         oXmlAttrib["height"].Value));


                    // Loop through each panel in the layout                
                    XmlNodeList oPanels = oXmlNode[i].ChildNodes;
                    Trace.Write("Panels in layout:  " + oPanels.Count.ToString());

                    for (int j = 0; j < oPanels.Count; j++)
                    {
                        XmlAttributeCollection oPanel = oPanels[j].Attributes;

                        sbPanelLayout.Append(string.Format("new Panel({0},{1},{2},{3},{4},{5},'{6}') ",
                                                              oPanel["id"].Value,
                                                              oPanel["width"].Value,
                                                              oPanel["height"].Value,
                                                              oPanel["x"].Value,
                                                              oPanel["y"].Value,
                                                              oPanel["border-width"].Value,
                                                              oPanel["border-color"].Value));

                        if (j + 1 < oPanels.Count)
                            sbPanelLayout.Append(",");
                    }

                    sbPanelLayout.Append(");" + Environment.NewLine);

                    // Add panel layout to panel layout array
                    sbJS.Append(sbPanelLayout.ToString());
                }

                litJS_PanelLayouts.Text = sbJS.ToString();

                Cache[CACHE_PANELLAYOUTS] = sbJS.ToString();
            }
        }
        else
        { // Cached

            Trace.Write("Panels", "Cached - Using cached code");

            litJS_PanelLayouts.Text = (string)Cache[CACHE_PANELLAYOUTS];
        }
    }
    
    // Format string for JavaScript
    string FormatForJavaScript(string sInput )
    {
        return sInput;
    }
    
    // ########################## Helper methods ###########################
    
    // Work out the preview dimensions
    void CalcPreviewDimensions(ref int iHeight, ref int iWidth)
    {
        double dblWidthResize = Convert.ToDouble(iWidth) / PREVIEW_MAXWIDTH;
        double dblHeightResize = Convert.ToDouble(iHeight) / PREVIEW_MAXHEIGHT;

        // Check that width resize creates a valid height
        if ((iHeight / dblWidthResize) <= PREVIEW_MAXHEIGHT)
        { // Use width based calculations
            iHeight = Convert.ToInt32(iHeight / dblWidthResize);
            iWidth = Convert.ToInt32(iWidth / dblWidthResize);
        }
        else
        { // Use height based calculations
            iHeight = Convert.ToInt32(iHeight / dblHeightResize);
            iWidth = Convert.ToInt32(iWidth / dblHeightResize);
        }

    }    

</script>

<script type="text/javascript" language="javascript">

    <asp:Literal runat="server" id="litJS_PanelLayouts" ></asp:Literal>
    <asp:Literal runat="server" id="litJS_SpriteCollections" ></asp:Literal>
    <asp:Literal runat="server" id="litJS_BackgroundCollections" ></asp:Literal>
    
    var bDebugMode = false; // Is debug mode enabled? (Show debug output window)
    
    // ################################ Structures ################################
    
    // An individual panel - Part of a panel layout
    function Panel( id, width, height, x, y, borderWidth, borderColor )
    {
        this._ID    = id;
        this._width = width;
        this._height = height;
        this._x = x;
        this._y = y;
        this._borderWidth = borderWidth;
        this._borderColor = borderColor;
    }
   
    // A comic sprite
    function Sprite( src, filename, width, height, previewWidth, previewHeight )
    {
        this._src           = src; // Relative address of image
        this._filename      = filename; // Just the filename
        this._width         = width;
        this._height        = height;
        this._PreviewWidth  = previewWidth; // Width of sprite in preview
        this._PreviewHeight = previewHeight;
    }    
   
    // A background
    function Background( src, filename, width, height, previewWidth, previewHeight )
    {
        this._src           = src; // Relative address of image
        this._filename      = filename; // Just the filename
        this._width         = width;
        this._height        = height;
        this._PreviewWidth  = previewWidth; // Width of background in preview
        this._PreviewHeight = previewHeight;    
    }
    
    // ###########################################################################
    
    // Add the available panel layouts into the dropdown
    function LoadPanelLayouts()
    {
        var oCombo = document.getElementById('PanelLayouts');
        
        // oCombo.options.clear();
        
        for ( var i = 0; i < oPanelLayouts.length; i++ )
        {
            var oPanelLayout = document.createElement("OPTION");
            oPanelLayout.text = oPanelLayouts[i][0];
            oPanelLayout.value = i;
            oCombo.options.add(oPanelLayout);
        }
    }
    
    // Display a background collection
    function ShowBackgroundCollection( iCollectionID )
    {
        var oDisplayDIV = document.getElementById('BackgroundCollectionPanel');
        var oBackgroundCollection = oBackgroundCollections[iCollectionID];
        
        // Remove anything currently in the background collection panel
        oDisplayDIV.innerHTML = '';
        
        // Loop through each background
        for ( var i = 0; i < oBackgroundCollection.length; i++ )
        {
            // Set-up background container 
			var oBackground = document.createElement('div');
			oDisplayDIV.appendChild( oBackground );        
            oBackground.id = 'Background' + i;
            oBackground.className = 'Background';
            
            // Add image
            var imgBackground = document.createElement('img');
            oBackground.appendChild( imgBackground );
            imgBackground.className = 'Background';
            
            // imgBackground.src = oBackgroundCollection[i]._src;
            // Resize background preview
            var sResizedBackground = 'ResizeImage.aspx?img=' + escape(oBackgroundCollection[i]._src);
            sResizedBackground += '&w=' + String( oBackgroundCollection[i]._PreviewWidth );
            sResizedBackground += '&h=' + String( oBackgroundCollection[i]._PreviewHeight );
            sResizedBackground += '&p=1' // Draw preview size
                    
            imgBackground.src = sResizedBackground;
           
            imgBackground.style.width = oBackgroundCollection[i]._PreviewWidth;
            imgBackground.style.height = oBackgroundCollection[i]._PreviewHeight;
            imgBackground.onclick = function(){ SetBackground_Default( this ) };
            // Set custom attributes
            imgBackground.backgroundSrc = oBackgroundCollection[i]._src;
            imgBackground.backgroundWidth = oBackgroundCollection[i]._width;
            imgBackground.backgroundHeight = oBackgroundCollection[i]._height;
            
            // Add filename
            var pFilename = document.createElement('p');
            oBackground.appendChild( pFilename );
            pFilename.className = 'BackgroundFilename';
            pFilename.innerText = oBackgroundCollection[i]._filename;
        }
    }    
    
    // Display a sprite collection
    function ShowSpriteCollection( iCollectionID )
    {
        var oDisplayDIV = document.getElementById('SpriteCollectionPanel');
        var oSpriteCollection = oSpriteCollections[iCollectionID];
        
        // Remove anything currently in the sprite collection panel
        oDisplayDIV.innerHTML = '';
        
        // Loop through each sprite
        for ( var i = 0; i < oSpriteCollection.length; i++ )
        {
            // Set-up sprite container 
		    var oSprite = document.createElement('div');
		    oDisplayDIV.appendChild( oSprite );        
            oSprite.id = 'Sprite' + i;
            oSprite.className = 'Sprite';
            
            // Add image
            var imgSprite = document.createElement('img');
            oSprite.appendChild( imgSprite );
            imgSprite.className = 'Sprite';
            imgSprite.src = oSpriteCollection[i]._src;
            imgSprite.style.width = oSpriteCollection[i]._PreviewWidth;
            imgSprite.style.height = oSpriteCollection[i]._PreviewHeight;
            imgSprite.onclick = function(){ AddSprite_Default( this ) };
            // Set custom attributes
            imgSprite.spriteSrc = oSpriteCollection[i]._src;
            imgSprite.spriteWidth = oSpriteCollection[i]._width;
            imgSprite.spriteHeight = oSpriteCollection[i]._height;
            
            // Add filename
            var pFilename = document.createElement('p');
            oSprite.appendChild( pFilename );
            pFilename.className = 'SpriteFilename';
            pFilename.innerText = oSpriteCollection[i]._filename;
        }
    }    

    function SetupLayout_Default()
    {
        var oCombo = document.getElementById('PanelLayouts');
        SetupLayout( oCombo.selectedIndex );
    }
    
    var iCurrentPanelLayoutID = -1;
    
    // Create the selected layout
    function SetupLayout( iPanelLayoutID )
    {
        var oCombo = document.getElementById('PanelLayouts');
        var oSelectedPanel = document.getElementById('SelectedPanel');
        var oPanelLayout = oPanelLayouts[ iPanelLayoutID ];
        var oPanels = document.getElementById('Panels'); // Where the generated panels get put
        
        // Remember current panel layout
        iCurrentPanelLayoutID = iPanelLayoutID;
        
        // Check if a panel layout already exists - if so, ask for confirmation before proceeding
        if ( oPanels.innerHTML.length > 0 )
        {
            if ( confirm('A panel layout already exists. Do you want to wipe the current layout and use the new layout?') )
            { // Continue
                oPanels.innerHTML = '';
            }
            else
            { // Abort
                return false;
            }
        }
        
        // Set-up master panel layout
        oPanels.style.width = oPanelLayout[1] + 'px';
        oPanels.style.height = oPanelLayout[2] + 'px';
        
        // Clear panel selector
        for ( var i = oSelectedPanel.options.length - 1; i >= 0; i-- )
            oSelectedPanel.remove(i);

        // Loop through each panel (Skip first three indexes - as it contains the name, width and height )
        for ( var i = 3; i < oPanelLayout.length; i++ )
        {
			var oElement = document.createElement('div');
			oPanels.appendChild( oElement );
			oElement.id = 'Panel' + oPanelLayout[i]._ID;
			oElement.style.overflow = 'hidden';
			oElement.style.position = 'absolute';   
			oElement.style.borderStyle = 'solid';
				
		    oElement.style.backgroundColor = 'white';		
			oElement.style.borderWidth = oPanelLayout[i]._borderWidth + 'px';
			oElement.style.borderColor = oPanelLayout[i]._borderColor;
			oElement.style.height = oPanelLayout[i]._height + 'px';
			oElement.style.width = oPanelLayout[i]._width + 'px';
			oElement.style.left = oPanelLayout[i]._x + 'px';         
			oElement.style.top = oPanelLayout[i]._y + 'px';		
			
            // Add panels to panel selector
            var oPanelSelector = document.createElement("OPTION");
            oPanelSelector.text = "Panel " + oPanelLayout[i]._ID;
            oPanelSelector.value = oPanelLayout[i]._ID;
            oSelectedPanel.options.add( oPanelSelector );			
        }
        
        // Clear selected objects
        drawObjReset();
    }
        
    // ################# Run time methods #################
   
    // AJAX communication object
    var oAJAX;
    
    function SetupAJAX( iMode )
    {
        oAJAX = getXMLHttpRequest();
        oAJAX.onreadystatechange = AJAXStateChange;    
        iAJAXResponseMode = iMode;
    }
    
    // What is the ID of the current comic?
    var iComicID = -1; // Intial value means new
    
    // How big is the resizer border that surrounds everything
    var iResizerSize = 10; // Pixels
    
    // Delete the currently selected comic object
    function DeleteSelectedComicObject()
    {
        // Check that something is selected
        if ( dragObjComic != null )
            if ( confirm('Are you sure that you want to delete the selected object?' ) )
            {
                // If object is textbox, also delete the tail
                if ( dragObjComic.typeID == 1 )
                    document.getElementById( 'TextboxTail' + dragObjComic.id ).parentNode.removeChild( document.getElementById( 'TextboxTail' + dragObjComic.id ) );    
            
                document.getElementById( dragObjComic.id ).parentNode.removeChild( document.getElementById( dragObjComic.id ) );
                drawObjReset(); // Clear selected objects
            }
    }
    
    function Save()
    {
        // If new comic - Get new comic ID
        if ( iComicID == -1 )
        {
            // If new comic, request a new comic ID
            SetupAJAX(1); // New comic ID
            oAJAX.open( 'GET', 'Save.aspx?newcomicid=true', false );
            oAJAX.send(null);            
            return;
        }
        
        SetupAJAX(-1); // Do nothing with return data

        // Create comic
        SaveFragment( 0, 'layoutid=' + (Number(iCurrentPanelLayoutID)+1) + 
                         '&name=' + escape( document.getElementById('ComicName').value ) + 
                         '&publishDate=' + GetSelectedValue('<%=ComicPublishYear.ClientID%>') + '/' + GetSelectedValue('<%=ComicPublishMonth.ClientID%>') + '/' + GetSelectedValue('<%=ComicPublishDay.ClientID%>' ) );
    
        // Reference object holding all the panels    
        var oPanels = document.getElementById('Panels');
       
        // Loop through panels
        for ( var iPanelID = 1; iPanelID <= oPanels.childNodes.length; iPanelID++  )
        {
            DebugShow( 'Saving panel ' + iPanelID );
            var oPanel = oPanels.childNodes[iPanelID-1];
        
            // Save panel settings
            SaveFragment( 1, 'id=' + iPanelID + '&bg=' + FormatBackground( oPanel.style.realBackgroundImage ) );
        
            DebugShow( "Saved panel" );
        
            // Panel content
            for ( var i = 0; i < oPanel.childNodes.length; i++ )
            {
                switch( oPanel.childNodes[i].typeID )
                {
                    case 0: // Sprites
                        DebugShow( 'Saving sprite ' + i );
                        var oSprite = oPanel.childNodes[i];
                        
                        // Reference the image into the resizer DIV
                        var oSpriteInner = document.getElementById('Sprite' + oSprite.id );
                        
                        var sFlip = '';
                        if ( oSpriteInner.style.filter.indexOf('fliph') != -1 ) sFlip += 'y';
                        if ( oSpriteInner.style.filter.indexOf('flipv') != -1 ) sFlip += 'x';
                        
                        // Save sprite
                        SaveFragment( 2, 'x=' + (Number(FormatDimension( oSprite.style.left )) + (iResizerSize) ) + 
                                         '&y=' + (Number(FormatDimension( oSprite.style.top )) + (iResizerSize) ) + 
                                         '&w=' + (Number(FormatDimension( oSprite.style.width )) - (iResizerSize*2) ) + 
                                         '&h=' + (Number(FormatDimension( oSprite.style.height )) - (iResizerSize*2) ) + 
                                         '&alpha=' + oSpriteInner.style.alpha + 
                                         '&flip=' + GetFlipSetting( oSpriteInner ) + 
                                         '&locked=' + oSprite.locked + 
                                         '&zIndex=' + oSprite.style.zIndex + 
                                         '&src=' + oSprite.spriteSrc );
                                                         
                        break;    
                    case 1: // Textbox
                        DebugShow( 'Saving textbox ' + i );
                        var oTextbox = oPanel.childNodes[i];
                        
                        // Reference the textbox into the resizer DIV
                        var oTextboxInner = document.getElementById('Textbox' + oTextbox.id );
                        
                        // Locate textbox tail
                        var oTextboxTail = document.getElementById('TextboxTail' + oTextbox.id );

                        // Save textbox
                        SaveFragment( 3, 'x=' + (Number(FormatDimension( oTextbox.style.left )) + (iResizerSize) ) + 
                                         '&y=' + (Number(FormatDimension( oTextbox.style.top )) + (iResizerSize) ) + 
                                         '&w=' + (Number(FormatDimension( oTextbox.style.width )) - (iResizerSize*2) ) + 
                                         '&h=' + (Number(FormatDimension( oTextbox.style.height )) - (iResizerSize*2) ) + 
                                         '&fontWeight=' + oTextboxInner.style.fontWeight + 
                                         '&fontSize=' + FormatDimension( oTextboxInner.style.fontSize ) + 
                                         '&fontStyle=' + oTextboxInner.style.fontStyle + 
                                         '&fontName=' + oTextboxInner.style.fontFamily + 
                                         '&colour=' + oTextboxInner.style.color + 
                                         '&backgroundColour=' + oTextboxInner.style.backgroundColor + 
                                         '&borderWidth=' + FormatDimension( oTextboxInner.style.borderWidth ) + 
                                         '&borderStyle=' + oTextboxInner.style.borderStyle + 
                                         '&borderColour=' + oTextboxInner.style.borderColor + 
                                         '&alpha=' + oTextboxInner.style.alpha + 
                                         '&textAlign=' + oTextboxInner.style.textAlign + 
                                         '&locked=' + oTextbox.locked + 
                                         '&tailEnabled=' + ( oTextboxTail.style.visibility == 'hidden' ? 'false' : 'true' ) + 
                                         '&tailX=' + (Number(FormatDimension( oTextboxTail.style.left ))+ 12) + 
                                         '&tailY=' + (Number(FormatDimension( oTextboxTail.style.top )) + 12) + 
                                         '&zIndex=' + oTextbox.style.zIndex + 
                                         '&text=' + escape( oTextboxInner.value ) );
                    
                        break;                                      
                }
            }
        }
        
        // Generate comic
        oAJAX.open( 'GET', 'Print.aspx?comicid=' + iComicID, false );
        oAJAX.send(null);  
        
        alert('Comic saved');
    }   
    
    // Check an objects flip setting
    function GetFlipSetting( oObject )
    {
        var sFlip = '';
        if ( oObject.style.filter.indexOf('fliph') != -1 ) sFlip += 'x';
        if ( oObject.style.filter.indexOf('flipv') != -1 ) sFlip += 'y';    
        return sFlip;
    }
    
    
    // Display the current comic
    function Preview()
    {
        window.open( 'Print.aspx?comicid=' + iComicID + '&preview=1', '', '', '' );
    }
    
    // Basically remove the px
    function FormatDimension( sInput )
    {
        sInput = sInput.replace( 'px', '' );
        sInput = sInput.replace( 'pt', '' );
        
        return sInput;
    }
    
    // Remove the 'url(' and the trailing ')'
    function FormatBackground( sInput )
    {
        if ( sInput != null )
            // return sInput.substring( 4, sInput.length - 1 );    
            return sInput;
        else
            return '';
    }

    // Save a small part of the comic     
    function SaveFragment( iMode, sData )
    {
        oAJAX.open( 'GET', 'Save.aspx?comicid=' + iComicID + '&m=' + iMode + '&' + sData, false );
        oAJAX.send(null);    
    }    
    
    // When AJAX data comes back, do what?
    var iAJAXResponseMode = -1;
    
    function AJAXStateChange()
    {
        if (oAJAX.readyState == XMLHTTPREQUEST_READY_STATE_COMPLETED)
        {
            if (oAJAX.status == 200)
            {
              
                switch( iAJAXResponseMode )
                {
                    case 1: // New comic ID
                        if ( oAJAX.responseXML.documentElement.getAttribute('comicid') != null )
                        {
                            iComicID = Number( oAJAX.responseXML.documentElement.getAttribute('comicid') );
                            Save(); // Now save comic with new comic ID
                        }
                        else
                            alert( 'Error generating new Comic ID' );
                        
                        break;
                    case 2: // Load comics
                        var oComicsList = document.getElementById('ComicList');
                        var oComics = oAJAX.responseXML.getElementsByTagName('comic');
                        
                        // Clear 
                        for (var i=oComicsList.options.length-1; i>=0; i--)
                            oComicsList.options[i] = null;
     
                        // Add comics                   
                        for (var i = 0; i < oComics.length; i++)
                        {
                            var oOption = document.createElement('option');
                            oOption.text = oComics[i].getAttribute('name');
                            oOption.value = oComics[i].getAttribute('comicid');
                            
                            oComicsList.add( oOption );
                        }
                        
                        break;
                    case 3: // Layout the loaded comic
                        LayoutLoadedComic();
                        break;
                }
                
                iAJAXResponseMode = -1; // Reset                
            }
        }
    }    
    
    function BodyLoaded()
    {
        LoadPanelLayouts();
        
        // Load the initial background and sprite collections
        ShowSpriteCollection(0);
        ShowBackgroundCollection(0);
    }
    
    function DebugShow( sMessage )
    {
        if ( bDebugMode )
            document.getElementById('DebugOutput').value += '\n' + sMessage;
    }
    
    // What is the currently selected panel?
    function GetCurrentPanel()
    {
        return GetSelectedValue( 'SelectedPanel' );
    }
    
    // Get the selected value of a list/dropdown box
    function GetSelectedValue( ObjectID )
    {
        var oObject = document.getElementById( ObjectID );
        
        if ( oObject.selectedIndex != -1 )
            return oObject.options[ oObject.selectedIndex ].value;    
        else
            return null;
    }
    
    var iNextElementID = 0;
    
    // Set the panel background
    function SetBackground( iPanelID, sBackground )
    {
        var oPanel = document.getElementById('Panel' + iPanelID );
        
        // Create resized background
        var sResizedBackground = 'ResizeImage.aspx?img=' + escape(sBackground);
        sResizedBackground += '&w=' + FormatDimension( oPanel.style.width );
        sResizedBackground += '&h=' + FormatDimension( oPanel.style.height );

        oPanel.style.backgroundImage = "url('" + sResizedBackground + "')"; // Auto resized background
        oPanel.style.realBackgroundImage = sBackground; // Actual background        
    }
    
    // Set the panel background
    function SetBackground_Default( oBackground )
    {
        SetBackground( GetCurrentPanel(), oBackground.backgroundSrc );
    }
    
    function AddSprite_Default( oSprite )
    {
        AddSprite( GetCurrentPanel(), 
                   oSprite.spriteSrc,  
                   oSprite.spriteWidth, 
                   oSprite.spriteHeight, 
                   10, // X
                   10,  // Y
                   ++dragObj.zIndex ); // Bring to front
    }
    
    function AddSprite( iPanelID, sSRC, Width, Height, x, y, zIndex )
    {
        var sElementID = iNextElementID++;
        var sElement = "<img src='" + sSRC + "' style='width:100%;height:100%;' id=\"Sprite" + sElementID + "\" />";
        	    
        // Adjust for resizer dimentions
        Width = Number(iResizerSize*2) + Number(Width);
        Height = Number(iResizerSize*2) + Number(Height);
        x = Number(x) - Number(iResizerSize);
        y = Number(y) - Number(iResizerSize);        	    
        	    
	    var oPanel = document.getElementById('Panel' + iPanelID );
	    var oElement = document.createElement('div');
	    oPanel.appendChild( oElement );
	    oElement.className = 'ResizerOuter';
	    oElement.id = sElementID;
	    oElement.style.width = Width;
	    oElement.style.height = Height;
	    oElement.style.left = x;
	    oElement.style.top = y;
	    oElement.style.position = 'absolute';
	    oElement.spriteSrc = sSRC; // Save sprite SRC as a custom property
	    oElement.typeID = 0; // Sprite
	    oElement.style.zIndex = zIndex;
    	
	    var sElementHTML = document.getElementById('ResizerDIV').innerHTML;
    	
	    sElementHTML = sElementHTML.replace(new RegExp(/###ELEMENT###/g), sElement ); 
	    sElementHTML = sElementHTML.replace(new RegExp(/###CONTAINERID###/g), sElementID ); 
    	
	    oElement.innerHTML = sElementHTML;    

        // Reference newly created object
        dragObjComic = document.getElementById(oElement.id);

        // Set initial properties
	    ChangeProperty();
	    
	    // Select newly created sprite
	    dragStart(null, oElement.id, null );
	    dragStop(null);
     }
    
    function CreateTextbox_Default()
    {
        CreateTextbox( GetCurrentPanel(),
                       200, // width
                       100, // height
                       10, // x
                       10, // y
                       ++dragObj.zIndex, // Z-Index, bring to front
                       -1, // tail x - default
                       -1 ); // tail y - default
    }
    
    function CreateTextbox( iPanelID, Width, Height, x, y, zIndex, tailX, tailY )
    {
        var sNewResizerID = iNextElementID++;
        
        var sElement = "<textarea id=\"Textbox" + sNewResizerID + "\" style=\"height:100%;width:100%;overflow:hidden;\"></textarea>";
        
        // Adjust for resizer dimentions
        Width = Number(iResizerSize*2) + Number(Width);
        Height = Number(iResizerSize*2) + Number(Height);
        x = Number(x) - Number(iResizerSize);
        y = Number(y) - Number(iResizerSize);
        
	    var oPanel = document.getElementById('Panel' + iPanelID );
	    var oElement = document.createElement('div');
	    oPanel.appendChild( oElement );
	    oElement.className = 'ResizerOuter';
	    oElement.id = sNewResizerID;
	    oElement.style.left = x + 'px';
	    oElement.style.top = y + 'px';	    
	    oElement.style.width = Width + 'px';
	    oElement.style.height = Height + 'px';
	    oElement.style.position = 'absolute';
	    oElement.typeID = 1; // Textbox
	    oElement.style.zIndex = zIndex;
	    
	    // Make a note of the textbox ID, in order to select after creation
	    var oTextboxID = oElement.id;
    	
	    var sElementHTML = document.getElementById('ResizerDIV').innerHTML;
    	
	    sElementHTML = sElementHTML.replace(new RegExp(/###ELEMENT###/g), sElement ); 
	    sElementHTML = sElementHTML.replace(new RegExp(/###CONTAINERID###/g), sNewResizerID ); 
    	
	    oElement.innerHTML = sElementHTML;      
	    
	    // Create a tail for the textbox
	    var oElement = document.createElement('div');
	    oPanel.appendChild( oElement );
	    oElement.id = 'TextboxTail' + sNewResizerID ;
	    oElement.style.left = ( tailX == -1 ? -1 : tailX ) + 'px';
	    oElement.style.top = ( tailY == -1 ? (Height + y + 10 ) : tailY ) + 'px';
	    oElement.style.position = 'absolute';    
	    oElement.style.zIndex = ++dragObj.zIndex; // Bring to front
	    oElement.style.cursor = 'move';
	    
	    // Set initial visibility
	    oElement.style.visibilty = ( document.getElementById('chkHasTail').checked ? 'visible' : 'hidden' );
	    
	    oElement.onmousedown = function(){ dragStartReadID(event, this, null ) };
	    
	    var sTailHTML = document.getElementById('TextboxTail').innerHTML;
   
	    oElement.innerHTML = sTailHTML;
	    
        // Reference newly created object
        dragObjComic = document.getElementById(oTextboxID);

        // Set initial properties
	    ChangeProperty();
	    ChangeTextProperty();
	    
	    // Select newly created textbox
	    dragStart(null, oTextboxID, null );
	    dragStop(null);	   
    }
    
    // Load the selected comic
    function LoadSelectedComic()
    {
        // Get selected comic ID
        var iLoadComicID = GetSelectedValue( 'ComicList' );
        
        if ( iLoadComicID != null )
        {
            iComicID = iLoadComicID;       
                    
            // Load comic via AJAX
            SetupAJAX(3); // Load comics
            oAJAX.open( 'GET', 'Load.aspx?comicid=' + iLoadComicID, false );
            oAJAX.send(null);   
        }
    }
    
    // Layout the loaded comic
    function LayoutLoadedComic()
    {
        var oXML = oAJAX.responseXML;
        
        // Panel layout
        SetupLayout( Number(oXML.documentElement.getAttribute('PanelLayoutID'))-1 );
        
        // Set name
        document.getElementById('ComicName').value = oXML.documentElement.getAttribute('Name');
        
        // Set release date
        var oReleaseDate = new Date();
        oReleaseDate.setTime( Date.parse( oXML.documentElement.getAttribute('DatePublish') ) );
        
        SetDropdownValue( document.getElementById('<%=ComicPublishDay.ClientID%>'), oReleaseDate.getDate() );
        SetDropdownValue( document.getElementById('<%=ComicPublishMonth.ClientID%>'),( oReleaseDate.getMonth()+1) );
        SetDropdownValue( document.getElementById('<%=ComicPublishYear.ClientID%>'), oReleaseDate.getFullYear() );
        
        // Loop through each panel
        var oPanels = oXML.getElementsByTagName('Panel');
        for ( var iPanelID = 1; iPanelID <= oPanels.length; iPanelID++ )
        {
            // Panel settings
            SetBackground( iPanelID, oPanels[iPanelID-1].getAttribute('BackgroundImage') );
            
            // Loop through sprites
            var oSprites = oPanels[iPanelID-1].getElementsByTagName('Sprite');
            for ( var iSpriteID = 0; iSpriteID < oSprites.length; iSpriteID++ )
            {
                AddSprite( iPanelID, 
                           oSprites[iSpriteID].getAttribute('Image'), 
                           oSprites[iSpriteID].getAttribute('width'), 
                           oSprites[iSpriteID].getAttribute('height'), 
                           oSprites[iSpriteID].getAttribute('x'), 
                           oSprites[iSpriteID].getAttribute('y'), 
                           oSprites[iSpriteID].getAttribute('zIndex') );
                           
                // Apply sprite attributes
                document.getElementById('chkLock').checked = ( oSprites[iSpriteID].getAttribute('locked') == 'true' ? true : false );
                document.getElementById('chkFlipX').checked = ( oSprites[iSpriteID].getAttribute('flip').indexOf('x') != -1 );
                document.getElementById('chkFlipY').checked = ( oSprites[iSpriteID].getAttribute('flip').indexOf('y') != -1 );
                
                SetDropdownValue( oAlpha, oSprites[iSpriteID].getAttribute('alpha') );

                ChangeProperty();             
            }
            
            // Loop through textboxes
            var oTextboxes = oPanels[iPanelID-1].getElementsByTagName('Textbox');
            for ( var iTextboxID = 0; iTextboxID < oTextboxes.length; iTextboxID++ )
            {
                var bTailEnabled = Boolean( oTextboxes[iTextboxID].getAttribute('tailEnabled') );
            
                CreateTextbox( iPanelID, 
                               oTextboxes[iTextboxID].getAttribute('width'),
                               oTextboxes[iTextboxID].getAttribute('height'),
                               oTextboxes[iTextboxID].getAttribute('x'),
                               oTextboxes[iTextboxID].getAttribute('y'),
                               oTextboxes[iTextboxID].getAttribute('zIndex'),
                               ( bTailEnabled ? oTextboxes[iTextboxID].getAttribute('tailX') : -1 ),
                               ( bTailEnabled ? oTextboxes[iTextboxID].getAttribute('tailY') : -1 ) );
                               
                // Apply textbox attributes
                document.getElementById('chkLock').checked = ( oTextboxes[iTextboxID].getAttribute('locked') == 'true' ? true : false );
                document.getElementById('chkFlipX').checked = ( oTextboxes[iTextboxID].getAttribute('flip').indexOf('x') != -1 );
                document.getElementById('chkFlipY').checked = ( oTextboxes[iTextboxID].getAttribute('flip').indexOf('y') != -1 );
                document.getElementById('chkIsBold').checked = ( oTextboxes[iTextboxID].getAttribute('fontWeight').length > 0 );
                document.getElementById('chkIsItalic').checked = ( oTextboxes[iTextboxID].getAttribute('fontStyle').length > 0 );
                                
                var oTextboxInner = document.getElementById('Textbox' + dragObjComic.id );
                
                SetDropdownValue( oFontName, oTextboxes[iTextboxID].getAttribute('fontName') );
                SetDropdownValue( oFontSize, oTextboxes[iTextboxID].getAttribute('fontSize') );
                SetDropdownValue( oFontColour, oTextboxes[iTextboxID].getAttribute('colour') );
                SetDropdownValue( oFontAlign, oTextboxes[iTextboxID].getAttribute('textAlign') );                
                SetDropdownValue( oBackgroundColor, oTextboxes[iTextboxID].getAttribute('backgroundColour') );
                SetDropdownValue( oBorderWidth, oTextboxes[iTextboxID].getAttribute('borderWidth') );
                SetDropdownValue( oBorderStyle, oTextboxes[iTextboxID].getAttribute('borderStyle') );
                SetDropdownValue( oBorderColour, oTextboxes[iTextboxID].getAttribute('borderColour') );
                SetDropdownValue( oAlpha, oTextboxes[iTextboxID].getAttribute('alpha') );
                
                // Set text
                oTextboxInner.value = oTextboxes[iTextboxID].getAttribute('text');
                
                ChangeProperty();
                ChangeTextProperty();
            }            
        }      
        
        // Get rid of menus - show the editor!        
        document.getElementById('Menu_Load').style.visibility = 'hidden';
        DisableAll( false ); 
    }
    
    // Automatically layout the property panels
    function AutoLayoutProperties()
    {
        // Work out window dimensions
        var iWindowWidth = document.body.clientWidth;
        var iWindowHeight = document.body.clientHeight;
        
        // Reference property windows
        var oProperties = document.getElementById('Properties');
        var oText = document.getElementById('Text');
        var oSprites = document.getElementById('Sprites');
        var oBackgrounds = document.getElementById('Backgrounds');
        var oComic = document.getElementById('Comic');
        
        // Properties - top right
        oProperties.style.top = '0px';
        oProperties.style.left = (iWindowWidth - Number(FormatDimension(oProperties.style.width))) + 'px';
        
        // Text - under properties
        oText.style.top = '350px';
        oText.style.left = (Number(FormatDimension(oProperties.style.left)) - 50 ) + 'px';
        
        // Sprites - to the left of text
        oSprites.style.top = oText.style.top;
        oSprites.style.left = (Number(FormatDimension(oText.style.left)) - Number(FormatDimension(oSprites.style.width)) - 10 ) + 'px';
        
        // Backgrounds - to the left of text and underneath sprites
        oBackgrounds.style.top = ( Number(FormatDimension(oSprites.style.top)) + 60 ) + 'px';
        oBackgrounds.style.left = oSprites.style.left;
        
        // Comic - Bottom left
        oComic.style.top =  (Number(FormatDimension(oBackgrounds.style.top)) + 60 ) + 'px';
        oComic.style.left = (Number(FormatDimension(oText.style.left)) - Number(FormatDimension(oComic.style.width)) - 10 ) + 'px';
        
    }
    
    // ################# Property change methods #################

    // Highlight lock status    
    function OnChange_Lock()
    {
        // Lock - show status                        
        var oTDLock = document.getElementById('trLock');
        oTDLock.style.backgroundColor = ( dragObjComic.locked ? '#F4F5A1' : 'white' );    
    }
    
    
    // Shrink/grow a property box
    function ToggleHeight( id, FullHeight, ShortHeight )
    {
        var oBox = document.getElementById(id);
        
        if ( oBox.style.height == FullHeight + 'px' )
            oBox.style.height = ShortHeight + 'px';
        else
            oBox.style.height = FullHeight + 'px';
    }
    
    // Bring the currently selected object to the front
    function BringToTop()
    {
        if ( dragObjComic != null )
        {
            dragObjComic.style.zIndex = ++dragObj.zIndex;
        
            // Update properties
            DisplayProperties();    
        }
    }
    
    // Send the currently selected object to the back
    function SendToBack()
    {
        if ( dragObjComic != null )
        {
            dragObjComic.style.zIndex = --dragObj.zIndexLow;
        
            // Update properties
            DisplayProperties();    
        }
    }    
    
    
    
    // Show textbox properties  
    function DisplayPropertiesText()
    {
        // Is a textbox selected?
        if ( dragObjComic != null && dragObjComic.typeID == 1 )
        {
            var oTextbox = document.getElementById('Textbox' + dragObjComic.id );
            var oTextboxTail = document.getElementById('TextboxTail' + dragObjComic.id );
       
            SetDropdownValue( oFontName, oTextbox.style.fontFamily ); // Font name
            SetDropdownValue( oFontColour, oTextbox.style.color ); // Font colour
            SetDropdownValue( oFontSize, FormatDimension( oTextbox.style.fontSize ) ); // Font colour
            SetDropdownValue( oFontAlign, FormatDimension( oTextbox.style.textAlign ) ); // Alignment
            
            document.getElementById('chkIsBold').checked = ( oTextbox.style.fontWeight == 'bolder' ? true : false );
            document.getElementById('chkIsItalic').checked = ( oTextbox.style.fontStyle == 'italic' ? true : false );
            document.getElementById('chkHasTail').checked = ( oTextboxTail.style.visibility == 'hidden' ? false : true );
            
            SetDropdownValue( oBorderWidth, FormatDimension( oTextbox.style.borderWidth ) ); // Border width
            SetDropdownValue( oBorderColour, oTextbox.style.borderColor ); // Border colour
            SetDropdownValue( oBackgroundColor, oTextbox.style.backgroundColor ); // Background colour
        }

    }
      
    // Show object general properties
    function DisplayProperties()
    {
        // Check object is sprite/textbox
        if (  dragObjComic != null && dragObjComic.typeID != null )
        {   
            var oObjectStyle = GetSelectedObjectStyle();
        
            switch( Number(dragObjComic.typeID) )
            {
                case 0: // Sprite
                    document.getElementById('PropertyName').value = 'Sprite ' + dragObjComic.id;
                    document.getElementById('PropertyDetails').value = dragObjComic.spriteSrc;                    
                    break;
                case 1: // Textbox
                    document.getElementById('PropertyName').value = 'Textbox ' + dragObjComic.id;
                    break;                    
            }
            
            
            document.getElementById('PropertyX').value = dragObjComic.style.left;
            document.getElementById('PropertyY').value = dragObjComic.style.top;
            document.getElementById('PropertyWidth').value = dragObjComic.style.width;
            document.getElementById('PropertyHeight').value = dragObjComic.style.height;
            document.getElementById('PropertyZ').value = dragObjComic.style.zIndex;
            
            // Filters
            document.getElementById('chkFlipX').checked = ( oObjectStyle.filter.indexOf( 'fliph' ) != -1 );
            document.getElementById('chkFlipY').checked = ( oObjectStyle.filter.indexOf( 'flipv' ) != -1 );
            
            SetDropdownValue( oAlpha, oObjectStyle.alpha ); // Alpha
            
            // Locked
            document.getElementById('chkLock').checked = ( dragObjComic.locked != null && dragObjComic.locked );
            
            // Highlight lock status    
            OnChange_Lock();
        }
    }
    
    // Change the properties of the currently selected textbox
    function ChangeTextProperty()
    {
        // Has something been selected?
        if ( dragObjComic != null )
        {
            // Is a textbox selected?
            if ( dragObjComic.typeID == 1 )
            {
                var oTextStyle = document.getElementById('Textbox' + dragObjComic.id ).style;
                var oTextTailStyle = document.getElementById('TextboxTail' + dragObjComic.id ).style;
            
                oTextStyle.fontFamily = oFontName.options[ oFontName.selectedIndex ].value;
                oTextStyle.color = oFontColour.options[ oFontColour.selectedIndex ].value;
                oTextStyle.fontSize = oFontSize.options[ oFontSize.selectedIndex ].value + 'pt';
                oTextStyle.textAlign =  oFontAlign.options[ oFontAlign.selectedIndex ].value;
                oTextStyle.backgroundColor = oBackgroundColor.options[ oBackgroundColor.selectedIndex ].value;
                oTextStyle.borderWidth = oBorderWidth.options[ oBorderWidth.selectedIndex ].value;
                oTextStyle.borderStyle = oBorderStyle.options[ oBorderStyle.selectedIndex ].value;
                oTextStyle.borderColor = oBorderColour.options[ oBorderColour.selectedIndex ].value;
                
                oTextStyle.fontWeight = ( document.getElementById('chkIsBold').checked ? 'bolder' : '' );
                oTextStyle.fontStyle = ( document.getElementById('chkIsItalic').checked ? 'italic' : '' );
                
                // Textbox tail
                oTextTailStyle.visibility = ( document.getElementById('chkHasTail').checked ? 'visible' : 'hidden' );
            }    
        }

    }
    
    // Change the properties of the currently selected object
    function ChangeProperty()
    {
        // Has something been selected?
        if ( dragObjComic != null )
        {
            // Is a textbox or sprite selected?
            if ( dragObjComic.typeID == 0 || dragObjComic.typeID == 1 )        
            {
                var oObjectStyle = GetSelectedObjectStyle();
                
                // Filters - Build up profile
                var sFilters = '';
                
                // Flip X
                if ( document.getElementById('chkFlipX').checked )
                    sFilters += 'fliph ';
                
                // Flip Y
                if ( document.getElementById('chkFlipY').checked )
                    sFilters += 'flipv ';
                                    
                // Alpha
                sFilters += 'alpha(opacity=' + oAlpha.options[ oAlpha.selectedIndex ].value + ')';
                oObjectStyle.alpha = oAlpha.options[ oAlpha.selectedIndex ].value;  
                
                // Alpha filters
                oObjectStyle.filter = sFilters;
                
                // Lock
                dragObjComic.locked = document.getElementById('chkLock').checked;
                if ( dragObjComic.locked != null && dragObjComic.locked )
                        dragObjComic.className = 'ResizerOuterLocked';
                else
                        dragObjComic.className = 'ResizerOuterSelected';
            
                // Highlight lock status    
                OnChange_Lock();
                        
                // If textbox - apply style to tail
                if ( dragObjComic.typeID == 1 )
                {
                    var oTextboxTail = document.getElementById('TextboxTail' + dragObjComic.id );
                    oTextboxTail.className = dragObjComic.className;
                    oTextboxTail.locked = dragObjComic.locked;
                }
            }        
        }    
    }
    
    // Add/remove an object filter
    function ChangeFilter( oObjectStyle, sFilterName, bEnable )
    {
        // Apply or remove filter
        if (bEnable)
        { // Remove it
            
            oObjectStyle.filter = oObjectStyle.filter.replace( ' ' + sFilterName, '' );    
        }
        else if ( !bEnable && oObjectStyle.filter.indexOf( sFilterName ) == -1 ) // Check that it's not already applied
        { // Apply it
        
            oObjectStyle.filter += ' ' + sFilterName;                    
        }
    }
    
    // Set dropdown value
    function SetDropdownValue( oDropdown, sValue )
    {
        for ( i = 0; i < oDropdown.options.length; i++ )
            if ( oDropdown.options[i].value.toLowerCase() == String(sValue).toLowerCase() )
            {
                oDropdown.selectedIndex = i;
                break;
            }    
    }    
    
    // Get a reference to the currently selected object (in the resizer container)
    function GetSelectedObjectStyle()
    {
        var oObjectStyle;
        
        if ( dragObjComic == null )
            return null;
        
        switch( dragObjComic.typeID )
        {
            case 0: // Sprite
                oObjectStyle = document.getElementById('Sprite' + dragObjComic.id ).style;
                break;
            case 1: // Textbox
                oObjectStyle = document.getElementById('Textbox' + dragObjComic.id ).style;
                break;
            default:
                return false;
        }   
        
        return oObjectStyle;
    }
    
</script>
<head>
    <link href="StripEditor.css" rel="Stylesheet" type="text/css" /> 
    <script type="text/javascript" src="AJAX.js" ></script>
    <script type="text/javascript" src="DHTML.js" ></script>
</head>
<body onload="BodyLoaded()" style="margin:0px;background-color:Gray;background-image:url(images/BackgroundLogo.png);background-repeat:no-repeat;background-position:right top;" >
    <form runat="server" >

        <!-- Panel layout gets generated in this DIV -->
	    <div id="Panels" style="position:absolute;top:0px;left:0px;" >
	    </div>

	    <div style="position:absolute;top:400px;left:50px;border:2px solid black;background-color:white;width:400px;" id="Comic" >
		    <div onmousedown="dragStart(event, 'Comic', null )" class="BoxHeading" >
			    Comic
		    </div>
		    <div style="height:150px;overflow:hidden;">
                <table style="width:100%;" cellspacing="0" cellpadding="2" >
                    <tr>
                        <td class="Property" style="width:50%;" >
                            Layouts
                        </td>
                        <td class="Property PropertySide" >
                           <select id="PanelLayouts" class="Property"  ></select> 
                           <input type="button" onclick="SetupLayout_Default()" class="Property"  value="Use" style="width:60px;"/>                     
                        </td>
                    </tr>	
                    <tr>
                        <td class="Property" style="width:50%;" >
                            Current panel
                        </td>
                        <td class="Property PropertySide" >
                           <select id="SelectedPanel" class="Property"  ></select>                   
                        </td>
                    </tr>   
                    <tr>
                        <td class="Property" style="width:50%;" >
                            Name
                        </td>
                        <td class="Property PropertySide" >
                           <input type="text" id="ComicName" style="width:100%;" class="Property" />                 
                        </td>
                    </tr>
                    <tr>
                        <td class="Property PropertyBottom" style="width:50%;" >
                            Release date
                        </td>
                        <td class="Property PropertySide PropertyBottom" >
                            <asp:DropDownList ID="ComicPublishDay" runat="server"></asp:DropDownList>
                            <asp:DropDownList ID="ComicPublishMonth" runat="server"></asp:DropDownList>
                            <asp:DropDownList ID="ComicPublishYear" runat="server"></asp:DropDownList>
                        </td>
                    </tr>    
                    <tr>
                        <td colspan="2">
                            <input id="Button6" type="button" value="Main menu" onclick="Startup_Splash()" />                        
                            <input id="Button3" type="button" value="Save" onclick="Save()" />
                            <input id="Button4" type="button" value="Preview" onclick="Preview()" />
                        </td>
                    </tr>            
                </table>		    
            </div>
	    </div>
    	
	    <div style="position:absolute;top:400px;left:550px;border:2px solid black;background-color:silver;width:350px;" id="Sprites" >
		    <div onmousedown="dragStart(event, 'Sprites', null )" class="BoxHeading" >
		        <input type="button" value="#" onclick="ToggleHeight('SpriteCollectionPanel',400, 1);" class="HeightToggle" />
			    Sprites 
		    </div>
		    <div>
                <asp:DropDownList ID="ddlSpriteFolders" runat="server" style="width:100%;" onchange="ShowSpriteCollection(this.selectedIndex);" ></asp:DropDownList>
            </div>
		    <div style="padding:5px;overflow-y:scroll;height:1px;" id="SpriteCollectionPanel" >
                <asp:Literal ID="litSprites" runat="server"></asp:Literal>
		    </div>
	    </div>	
	    
    	
	    <div style="position:absolute;top:500px;left:450px;border:2px solid black;background-color:silver;width:350px;" id="Backgrounds" >
		    <div onmousedown="dragStart(event, 'Backgrounds', null )" class="BoxHeading" >
		        <input type="button" value="#" onclick="ToggleHeight('BackgroundCollectionPanel',400, 1);" class="HeightToggle" />
			    Backgrounds
		    </div>
		    <div>
                <asp:DropDownList ID="ddlBackgroundFolders" runat="server" style="width:100%;" onchange="ShowBackgroundCollection(this.selectedIndex);"></asp:DropDownList>
            </div>		    
		    <div style="padding:5px;height:1px;overflow-y:scroll;" id="BackgroundCollectionPanel" >
                <asp:Literal ID="litBackgrounds" runat="server"></asp:Literal>
		    </div>
	    </div>		
    	
	    <div style="position:absolute;top:400px;left:850px;border:2px solid black;background-color:white;" id="Debug" >
		    <div onmousedown="dragStart(event, 'Debug', null )" class="BoxHeading" >
			    Debug
		    </div>
		    <div style="padding:5px;width:350px;height:200px;overflow:scroll;">
                <textarea style="width:100%;height:100%;" id="DebugOutput" ></textarea>
		    </div>
	    </div>		

	    <div style="position:absolute;top:400px;left:850px;border:2px solid black;background-color:white;width:200px;" id="Properties" >
		    <div onmousedown="dragStart(event, 'Properties', null )" class="BoxHeading" >
		        <input type="button" value="#" onclick="ToggleHeight('PropertiesContent',305, 1);" class="HeightToggle" />
			    Properties
		    </div>
		    <div style="padding:0px;height:305px;overflow:hidden;" id="PropertiesContent">
		    
		        <input id="PropertyName" style="width:100%;border:0px;background-color:#EEEEEE;border-bottom:1px solid #BBBBBB;" type="text" readonly="readonly" />
		        <input id="PropertyDetails" style="width:100%;color:gray;border:0px;font-size:10px;" type="text" readonly="readonly" />
                
                <table style="width:100%;" cellspacing="0" cellpadding="2" >
                    <tr>
                        <td class="Property" style="width:50%;" >
                            X
                        </td>
                        <td class="Property PropertySide" >
                            <input id="PropertyX" type="text" maxlength="5" class="Property" />
                        </td>
                    </tr>
                    <tr>
                        <td class="Property" style="width:50%;" >
                            Y
                        </td>
                        <td class="Property PropertySide" >
                            <input id="PropertyY" type="text" maxlength="5" class="Property"  />         
                        </td>
                    </tr>
                    <tr>
                        <td class="Property" style="width:50%;" >
                            Width
                        </td>
                        <td class="Property PropertySide" >
                            <input id="PropertyWidth" type="text" maxlength="5" class="Property" />
                        </td>
                    </tr>
                    <tr>
                        <td class="Property" style="width:50%;" >
                            Height
                        </td>
                        <td class="Property PropertySide" >
                            <input id="PropertyHeight" type="text" maxlength="5" class="Property" />
                        </td>
                    </tr>   
                    <tr>
                        <td class="Property" style="width:50%;" >
                            Z index
                        </td>
                        <td class="Property PropertySide" >
                            <input id="PropertyZ" type="text" maxlength="3" class="Property" />
                            <input id="Button5" type="button" value="Send to back /\" onclick="SendToBack()" class="Property" />                            
                            <input id="Button1" type="button" value="Bring to top \/" onclick="BringToTop()" class="Property" />                            
                        </td>
                    </tr>  
		            <tr>
		                <td class="Property" >
		                    Alpha
		                </td>
		                <td class="Property PropertySide" >
	                        <asp:DropDownList ID="ddlAlpha" runat="server" onchange="ChangeProperty()" CssClass="Property">
                            </asp:DropDownList>			                
		                </td>		                
		            </tr>                    
                    <tr>
                        <td colspan="2" class="Property PropertySide">
                            <label for="chkFlipX">Flip X</label><input id="chkFlipX" type="checkbox" onclick="ChangeProperty()" />                    
                            <label for="chkFlipY">Flip Y</label><input id="chkFlipY" type="checkbox" onclick="ChangeProperty()" />                    
                        </td>
                    </tr>    
                    <tr id="trLock" >
                        <td colspan="2" class="Property PropertySide PropertyBottom" >
                            <label for="chkLock">Lock object</label><input id="chkLock" type="checkbox" onclick="ChangeProperty()" />                    
                        </td>
                    </tr>                                                                                             
                </table>   
                
                <input id="Button2" type="button" value="Delete" style="width:100%" class="Property" onclick="DeleteSelectedComicObject()" style="margin-top:5px;background-color:#FFE1E1;"/>                 
		    </div>
	    </div>	
	    
	    <div style="position:absolute;top:50px;left:850px;border:2px solid black;background-color:white;width:250px;" id="Text"  >
		    <div onmousedown="dragStart(event, 'Text', null )" class="BoxHeading" >
		        <input type="button" value="#" onclick="ToggleHeight('TextContent',310, 1);" class="HeightToggle" />
			    Text
		    </div>
		    <div style="height:310px;overflow:hidden;" id="TextContent" >
                <input  type="button" value="Create textbox" onclick="CreateTextbox_Default()" Class="Property" />
                
                <table style="width:100%;" cellspacing="0" cellpadding="2" >
                    <tr>
                        <td class="Property" style="width:50%;" >
                            Font
                        </td>
                        <td class="Property PropertySide" >
                           <asp:DropDownList ID="ddlFontName" runat="server" onchange="ChangeTextProperty()" CssClass="Property"  >
                            </asp:DropDownList>                        
                        </td>
                    </tr>
                    <tr>
                        <td class="Property" >
                            Colour
                        </td>
                        <td class="Property PropertySide" >
                            <asp:DropDownList ID="ddlFontColour" runat="server" onchange="ChangeTextProperty()" CssClass="Property" >
                            </asp:DropDownList>                             
                        </td>
                    </tr>
                    <tr>
                        <td class="Property" >
                            Size
                        </td>
                        <td class="Property PropertySide" >
                            <asp:DropDownList ID="ddlFontSize" runat="server" onchange="ChangeTextProperty()" CssClass="Property" >
                            </asp:DropDownList>                        
                        </td>
                    </tr>
                    <tr>
                        <td class="Property" >
                            Alignment
                        </td>
                        <td class="Property PropertySide" >
                            <asp:DropDownList ID="ddlFontAlign" runat="server" onchange="ChangeTextProperty()" CssClass="Property" >
                            </asp:DropDownList>                        
                        </td>
                    </tr>                    
                    <tr>
                        <td colspan="2" class="Property PropertySide" >
                            <label for="chkIsBold">Is bold</label><input id="chkIsBold" type="checkbox" onclick="ChangeTextProperty()" CssClass="Property" />
                            <label for="chkIsItalic">Is italic</label><input id="chkIsItalic" type="checkbox" onclick="ChangeTextProperty()" CssClass="Property" />        
                            <br />
                            <label for="chkHasTail">Has tail (speech bubble)</label><input id="chkHasTail" type="checkbox" onclick="ChangeTextProperty()" CssClass="Property" checked="true" />        
                        </td>
                    </tr>
                </table>
		        
		        <table style="width:100%;" cellspacing="0" cellpadding="2" >
		            <tr>
		                <td colspan="2" style="padding:0px;">
		                    <div class="BoxHeading" style="cursor:default;" >
			                    Text box
		                    </div>  		                
		                </td>
		            </tr>
		            <tr>
		                <td class="Property" style="width:50%;" >
		                    Border width
		                </td>
		                <td class="Property PropertySide" >
                            <asp:DropDownList ID="ddlBorderWidth" runat="server" onchange="ChangeTextProperty()" CssClass="Property">
                            </asp:DropDownList>		                
		                </td>		                
		            </tr>
		            <tr>
		                <td class="Property" >
		                    Border style
		                </td>
		                <td class="Property PropertySide" >
                            <asp:DropDownList ID="ddlBorderStyle" runat="server" onchange="ChangeTextProperty()" CssClass="Property">
                            </asp:DropDownList>		                
		                </td>		                
		            </tr>
		            <tr>
		                <td class="Property PropertyBottom" >
		                    Border colour
		                </td>
		                <td class="Property PropertySide PropertyBottom" >
                            <asp:DropDownList ID="ddlBorderColour" runat="server" onchange="ChangeTextProperty()" CssClass="Property">
                            </asp:DropDownList>			                
		                </td>		                
		            </tr>
		            <tr>
		                <td colspan="2" >
		                    &nbsp;
		                </td>
		            </tr>
		            <tr>
		                <td class="Property PropertyBottom" >
		                    Back colour
		                </td>
		                <td class="Property PropertySide PropertyBottom" >
		                    <asp:DropDownList ID="ddlBackgroundColour" runat="server" onchange="ChangeTextProperty()" CssClass="Property">
                            </asp:DropDownList>			                
		                </td>		                
		            </tr>
		        </table>
                		                  
		    </div>
	    </div>		    

    </form>
</body>


    <!-- This is the DIV that gets cloned to create resizable content -->
	<div class="ResizerOuter" id="ResizerDIV" style="visibility:hidden;" >
		<table style="width:100%;height:100%;cursor:move;" cellpadding="0" cellspacing="0" >
			<tr style="height:10px;" >
				<td style="width:10px;text-align:left;"><img src="Resizer.gif" class="Resizer" style="cursor:NW-resize;" onmousedown="dragStart(event, '###CONTAINERID###', 'nw')" /></td>
				<td style="text-align:center;" onmousedown="dragStart(event, '###CONTAINERID###', null)" ><img src="Resizer.gif" class="Resizer" style="cursor:N-resize;" onmousedown="dragStart(event, '###CONTAINERID###', 'n')" /></td>
				<td style="width:10px;text-align:right;"><img src="Resizer.gif" class="Resizer" style="cursor:NE-resize;" onmousedown="dragStart(event, '###CONTAINERID###', 'ne')" /></td>
			</tr>
			<tr>
				<td style="width:10px;vertical-align:middle;text-align:left;" onmousedown="dragStart(event, '###CONTAINERID###', null)"  ><img src="Resizer.gif" class="Resizer" style="cursor:W-resize;" onmousedown="dragStart(event, '###CONTAINERID###', 'w')" /></td>
				<td>
					<div style="height:100%;width:100%;cursor:default;" >
						###ELEMENT###
					</div>
				</td>
				<td style="width:10px;vertical-align:middle;text-align:right;" onmousedown="dragStart(event, '###CONTAINERID###', null)" ><img src="Resizer.gif" class="Resizer" style="cursor:E-resize;" onmousedown="dragStart(event, '###CONTAINERID###', 'e')"/></td>
			</tr>
			<tr style="height:10px;" >
				<td style="width:10px;text-align:left;"><img src="Resizer.gif" class="Resizer" style="cursor:SW-resize;" onmousedown="dragStart(event, '###CONTAINERID###', 'sw')" /></td>
				<td style="text-align:center;" onmousedown="dragStart(event, '###CONTAINERID###', null)" ><img src="Resizer.gif" class="Resizer" style="cursor:S-resize;" onmousedown="dragStart(event, '###CONTAINERID###', 's')"  /></td>
				<td style="width:10px;text-align:right;"><img src="Resizer.gif" class="Resizer" style="cursor:SE-resize;" onmousedown="dragStart(event, '###CONTAINERID###', 'se')" /></td>
			</tr>
		</table>
	</div>
	
	<!-- This is the DIV that gets cloned to create the textbox tail -->
	<div id="TextboxTail" style="visibility:hidden;" ><img src="images/TextboxTail.gif" /></div>
	

    <!-- Grey out whole screen -->
    <div id="DisableAll" style="filter:alpha(opacity=80);background-color:black;width:100%;height:100%;top:0px;left:0px;position:absolute;z-index:5000;visibility:hidden;" >
    </div>
    
    <div id="Menu_Startup" style="border:3px solid black;position:absolute;width:500px;height:250px;background-color:white;top:0px;left:0px;z-index:5001;visibility:hidden;">
        <div>
            <img src="images/SplashScreen.png" />
        </div>
        <div style="height:100px;padding:5px;">
            <p>
               Let's make some comics! Shall we start fresh or plagiarize?
            </p>
            <input type="button" onclick="Startup_New();" value="New" style="width:49%;font-size:24px;border:1px solid grey;"/>
            <input type="button" onclick="Startup_Load();" value="Load" style="width:49%;font-size:24px;border:1px solid grey;"/>                    
        </div>        
    </div>

    <div id="Menu_Load" style="border:3px solid black;position:absolute;width:400px;height:600px;background-color:white;top:0px;left:0px;z-index:5002;visibility:hidden;">
	    <div class="BoxHeading" >
		    Load
	    </div>
	    <div>    
            <select id="ComicList" size="25" class="Property" style="width:100%;">
            </select>   
	    </div>
       <div style="height:100px;padding:5px;">
            <input type="button" onclick="LoadSelectedComic()" value="Load" style="width:49%;font-size:24px;border:1px solid grey;"/>
            <input type="button" onclick="Startup_Splash()" value="Cancel" style="width:49%;font-size:24px;border:1px solid grey;"/>                    
        </div>   	    
    </div>
    
	
<script type="text/javascript" >

    // Global reference and page loaded style events

    // Reference dropdowns
    var oFontName = document.getElementById('<%=ddlFontName.ClientID%>');
    var oFontColour = document.getElementById('<%=ddlFontColour.ClientID%>');
    var oFontSize = document.getElementById('<%=ddlFontSize.ClientID%>');
    var oFontAlign = document.getElementById('<%=ddlFontAlign.ClientID%>');
    var oBackgroundColor = document.getElementById('<%=ddlBackgroundColour.ClientID%>');
    var oAlpha = document.getElementById('<%=ddlAlpha.ClientID%>');
    var oBorderWidth = document.getElementById('<%=ddlBorderWidth.ClientID%>');
    var oBorderStyle = document.getElementById('<%=ddlBorderStyle.ClientID%>');
    var oBorderColour = document.getElementById('<%=ddlBorderColour.ClientID%>');   

    // Show/hide debug output
    document.getElementById('Debug').style.visibility = ( bDebugMode ? 'visible' : 'hidden' );

    // Set-up AJAX 
    SetupAJAX(-1);

    // Automatically layout the property panels
    AutoLayoutProperties();
    
    
    // ############################## TEMP PROGRAMMING
    
    
    var iWindowWidth = Number(document.body.clientWidth);
    var iWindowHeight = Number(document.body.clientHeight);
    
    var oTemp = document.getElementById('Menu_Startup');
    
    oTemp.style.top = (iWindowHeight / 2) - (Number(FormatDimension(oTemp.style.height)/2));
    oTemp.style.left = (iWindowWidth / 2) - (Number(FormatDimension(oTemp.style.width)/2));

    var oLoad = document.getElementById('Menu_Load');
    
    oLoad.style.top = (iWindowHeight / 2) - (Number(FormatDimension(oLoad.style.height)/2));
    oLoad.style.left = (iWindowWidth / 2) - (Number(FormatDimension(oLoad.style.width)/2));


    // Disable the whole screen    
    function DisableAll( bDisable )
    {
        document.getElementById('DisableAll').style.visibility = ( bDisable ? 'visible' : 'hidden' );
    }
    
    function Startup_Splash()
    {
        DisableAll( true );
        
        document.getElementById('Menu_Startup').style.visibility = 'visible';
        document.getElementById('Menu_Load').style.visibility = 'hidden';
    }
    
    function Startup_New()
    {
        DisableAll( false );
        document.getElementById('Menu_Startup').style.visibility = 'hidden';
    }
    
    function Startup_Load()
    {
        // Hide start interface
        document.getElementById('Menu_Startup').style.visibility = 'hidden';
    
        // Show load interface
        document.getElementById('Menu_Load').style.visibility = 'visible';
    
        // Load comics via AJAX
        iAJAXResponseMode = 2; // List comics
        oAJAX.open( 'GET', 'Load.aspx', false );
        oAJAX.send(null); 
    }
    
    Startup_Splash();
    
    // Auto load comic
    /*
    SetupAJAX(3); // Load comics
    oAJAX.open( 'GET', 'Load.aspx?comicid=127', false );
    oAJAX.send(null);   
    */
    
</script>
